@@ -7,7 +7,7 @@ from .widgets.dropdown import Dropdown
 from .widgets.text import Text
 from .widgets.text_field import TextField
 from .widgets.radio_button_group import RadioButtonGroup
-from .widgets.container import Container,Decoration
+from .widgets.container import Container,BoxDecoration
 from .widgets.scroll_view import ScrollView
 from .widgets.center import Center
 from .widgets.alignment import MainAxisAlignment,CrossAxisAlignment
@@ -17,4 +17,7 @@ from .widgets.loader import Loader
 from .widgets.file_input import FileInput
 from .widgets.image import Image
 from .widgets.horizontal_filled_pill import HorizontalFilledPill
+from .widgets.menu_region import MenuRegion,MenuItem,MenuClickType
+from .widgets.file_list import FileList,FileListItem
+from .widgets.icon import Icon,Icons,IconSize
 from .main_module import CollieWatch,CollieWatchHtmlEvents
\ No newline at end of file
