@@ -21,6 +21,7 @@ from secrets import token_hex
 from collections import deque
 import atexit
 import uuid
+import inspect
 from supabase import create_client,Client
 import websockets.client as websockets 
 import websockets.exceptions as websockets_exceptions
@@ -241,18 +242,23 @@ class CollieWatch:
                 if message["type"] == CollieWatchEvent.HTML_EVENT:
                     if message["data"]["type"] in CollieWatchHtmlInternalEvents.internal_events:
                         if message["data"]["type"] == CollieWatchHtmlInternalEvents.SENDING_FILE_CHUNK:
-                            print("HIER")
+                            
                             if CollieWatch.__file_chunks_pool.get(message["data"]["target_id"]) == None:
                                 CollieWatch.__file_chunks_pool[message["data"]["target_id"]] = []
                             
                             #receiving individual chunks
                             CollieWatch.__file_chunks_pool[message["data"]["target_id"]] += _dict_to_ordered_list(message["data"]["chunk"])
                             
+                            print(f"Receiving file chunk for {message['data']['target_id']}, {len(CollieWatch.__file_chunks_pool[message['data']['target_id']])} bytes received")
+                            
+
                             if message["data"]["target_id"] in CollieWatch.__callbacks_map and  CollieWatch.__callbacks_map[message["data"]["target_id"]].get(CollieWatchHtmlInternalEvents.SENDING_FILE_CHUNK):
                                     callback = lambda a=message["data"]:  CollieWatch.__callbacks_map[a["target_id"]][CollieWatchHtmlInternalEvents.SENDING_FILE_CHUNK]({"type":CollieWatchHtmlInternalEvents.SENDING_FILE_CHUNK,"target_id": a["target_id"],"chunk":a["chunk"]})
                                     CollieWatch.__callbacks_to_call_sync.put(callback)
 
                             if message["data"]["last_chunk"]:
+
+                                print("last chunk")
                                 
                                 callback_to_use = lambda a=message["data"],b=CollieWatch.__file_chunks_pool[message["data"]["target_id"]]: CollieWatch.__html_event_callback({"type":CollieWatchHtmlEvents.RECEIVED_FILE,"target_id": a["target_id"],"file":bytes(b),"file_name":a["file_name"]})
                                 
@@ -268,11 +274,11 @@ class CollieWatch:
 
                         continue
                     
-                    CollieWatch.__callbacks_to_call_sync.put(lambda a=message["data"]: CollieWatch.__html_event_callback(a))
+                    CollieWatch.__callbacks_to_call_sync.put(lambda a=message["data"]: CollieWatch.__html_event_callback(a) if len(inspect.signature(CollieWatch.__html_event_callback).parameters) > 0 else CollieWatch.__html_event_callback())
                     if message["data"]["target"].get("id") and CollieWatch.__callbacks_map.get(message["data"]["target"]["id"]):
                         if CollieWatch.__callbacks_map[message["data"]["target"]["id"]].get(message["data"]["type"]):
                             callback = CollieWatch.__callbacks_map[message["data"]["target"]["id"]][message["data"]["type"]]
-                            CollieWatch.__callbacks_to_call_sync.put(lambda a=message["data"]: callback(a))
+                            CollieWatch.__callbacks_to_call_sync.put(lambda a=message["data"]: callback(a) if len(inspect.signature(callback).parameters) > 0 else callback())
                     
                         
                 if message['type'] == CollieWatchEvent.CHILDREN_NOT_FOUND_WITH_ID:
