@@ -1,6 +1,6 @@
 from .widget import Widget
 
-class Decoration:
+class BoxDecoration:
     def __init__(self, color=None, border=None,border_radius=None):
         self.color = color
         self.border = border
